@@ -24,7 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <tqvbox.h>
 
 // KDE
-#include <kfilemetainfo.h>
+#include <tdefilemetainfo.h>
 class TQTextEdit;
 
 namespace Gwenview {
@@ -33,7 +33,7 @@ class Document;
 
 class MetaEdit : public TQVBox {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	MetaEdit(TQWidget *parent, Document*, const char *name="");
 	~MetaEdit();
