@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
  
  This program is free software; you can redistribute it and/or
@@ -22,19 +22,19 @@ Copyright 2000-2004 Aurlien Gteau
 #define EXTERNALTOOLACTION_H
 
 // KDE
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kurl.h>
 
 class KService;
 
 namespace Gwenview {
 /**
- * A specialized version of KAction, which is aware of the tool to run as well
+ * A specialized version of TDEAction, which is aware of the tool to run as well
  * as the urls to call it with.
  */
-class ExternalToolAction : public KAction {
+class ExternalToolAction : public TDEAction {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	ExternalToolAction(TQObject* parent, const KService*, const KURL::List&);
 	
