@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
 
 This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <tqcolor.h>
 
 // KDE includes
-#include <kfileview.h>
+#include <tdefileview.h>
 namespace Gwenview {
 
 class FileViewBase : public KFileView {
